@@ -4,7 +4,7 @@
 """
 import json
 
-__version__ = '3.1.0'
+__version__ = '3.2.0'
 __author__ = 'Fred Wang (taobao-pysdk@1e20.com)'
 
 import time
@@ -27,6 +27,7 @@ VALUE_TO_STR = {
     type(datetime.now()): lambda v: v.strftime('%Y-%m-%d %H:%M:%S'),
     type(u'a'): lambda v: v.encode('utf-8'),
     type(0.1): lambda v: "%.2f" % v,
+    type(True): lambda v: str(v).lower(),
     type(None): lambda x: ''
 }
 
@@ -98,7 +99,12 @@ class DefaultAPIRequest(BaseAPIRequest):
 
     def open(self, data, files):
         r = requests.post(self.url, data, files=files, headers={'Accept-Encoding': 'gzip'})
-        return r.json()
+        try:
+            return r.json()
+        except ValueError, e:
+            return {
+                "error_response": {"msg": "json decode error", "sub_code": "ism.json-decode-error",
+                                   "code": 15, "sub_msg": "json-error: %s || %s" % (str(e), r.text)}}
 
 
 class TaoBaoAPIError(StandardError):
